/*-----------------------------------------------------------------------------------*
 * Ball on a springy arc.
 * Press mouse to give energy, move cursor to alter parameters.
 *
 * Created by Daniel Jones, 2009
 * http://www.erase.net/
 *-----------------------------------------------------------------------------------*/

ArcSpring spring;

void setup()
{
  frameRate(120);
  size(600, 600);
  smooth();
  noFill();
  ellipseMode(CENTER);
  
  spring = new ArcSpring();
}

void draw()
{
  background(0);
  stroke(255);
  
  // draw grid
  strokeWeight(0.2);
  line(0, height / 2, width, height / 2);
  line(width / 2, 0, width / 2, height);

  // give coords from centre point
  pushMatrix();
  translate(width / 2, height / 2);
  strokeWeight(2);
  ellipse(0, 0, 5, 5);
  
  // update spring
  spring.step();
  float angle = spring.getAngle();
  
  // draw rotating ball
  strokeWeight(1.0 + (3.0 - spring.k * 3));
  line(0, 0, spring.getX(), spring.getY());
  strokeWeight(4);
  ellipse(spring.getX(), spring.getY(), 15.0 * log(spring.mass) - 5.0, 15.0 * log(spring.mass) - 5.0);
  
  popMatrix();
}

void mousePressed()
{
  spring.spinBy(HALF_PI * (int) random(1, 5));
}

void mouseMoved()
{
  // map spring constant and mass to mouse position
  float x = (float) mouseX / width;
  float y = (float) mouseY / height;
  
  spring.k = x;
  spring.mass = map(y, 0, 1, 10, 100);
}
